@@ -20,6 +20,7 @@ pub struct StorageData {
     pub room_to_name: BTreeMap<RoomId, Box<RoomName>>,
     pub room_to_direct_name: BTreeMap<RoomId, String>,
     pub recent_event_ids: Vec<EventId>,
+    pub last_sent_messages: Vec<(RoomId, String)>,
 }
 
 #[derive(Clone, Debug, Serialize, Deserialize, Default)]
@@ -384,7 +385,7 @@ impl Client {
             .unwrap();
         ruma::RoomId::try_from(this_room_id_val["room_id"].as_str().unwrap()).unwrap()
     }
-    pub fn send_message(&self, room_id: RoomId, message: impl Into<String>) {
+    pub fn send_message(&mut self, room_id: RoomId, message: impl Into<String>) {
         let msg = message.into();
         let txid = Uuid::new_v4()
             .to_simple()
@@ -396,6 +397,7 @@ impl Client {
             None,
         )
         .unwrap();
+        self.data.last_sent_messages.push((room_id.clone(), msg));
     }
 
     pub fn extract_data(&mut self, sync_results: EventResponse) -> Vec<MessageInfo> {
@@ -489,9 +491,6 @@ impl Client {
                         message_event
                     {
                         let sender = room_message.sender;
-                        if sender == self.me {
-                            return None;
-                        }
                         let message: String;
                         let is_emote: bool;
                         if let room::message::MessageType::Text(text_message_event_content) =
@@ -508,6 +507,14 @@ impl Client {
                         } else {
                             return None;
                         }
+                        if sender == self.me {
+                            //return None;
+                            let look_for = &(room_id.clone(), message.clone());
+                            if self.data.last_sent_messages.contains(&look_for) {
+                                self.data.last_sent_messages.retain(|q| q != look_for);
+                                return None;
+                            }
+                        }
                         return Some(MessageInfo {
                             message: message.clone(),
                             sender: sender,
